//                                               -*- C++ -*-
/**
 *  @file  EnumerateFunction.hxx
 *  @brief The bijective function to select polynomials in the orthogonal basis
 *
 *  (C) Copyright 2005-2010 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-05-21 17:44:02 +0200 (Wed, 21 May 2008) $
 *  Id:      $Id: Object.hxx 818 2008-05-21 15:44:02Z dutka $
 */
#ifndef OPENTURNS_ENUMERATEFUNCTION_HXX
#define OPENTURNS_ENUMERATEFUNCTION_HXX

#include "PersistentObject.hxx"
#include "Indices.hxx"


namespace OpenTURNS
{

  namespace Uncertainty
  {

    namespace Algorithm
    {

      /**
       * @class EnumerateFunction
       *
       * The bijective function to select polynomials in the orthogonal basis
       */

      class EnumerateFunction
	: public Base::Common::PersistentObject
      {
	CLASSNAME;
      public:

	typedef Base::Common::StorageManager StorageManager;
	typedef Base::Type::Indices          Indices;

	/** Default constructor */
	EnumerateFunction();

	/** Parameter constructor */
	EnumerateFunction(const UnsignedLong dimension);

	/** Virtual constrcutor */
	virtual EnumerateFunction * clone() const;

	/** String converter */
	virtual String __repr__() const;

	/** The bijective association between an integer and a set of indices */
	virtual Indices operator() (const UnsignedLong index) const;

	/** The inverse of the association */
	virtual UnsignedLong inverse(const Indices & indices) const;

	/** The cardinal of the given strate */
	virtual UnsignedLong getStrateCardinal(const UnsignedLong strateIndex) const;

	/** The cardinal of the cumulated strate above or equal to the given strate */
	virtual UnsignedLong getStrateCumulatedCardinal(const UnsignedLong strateIndex) const;
 
	/** Dimension accessor */
	void setDimension(const UnsignedLong dimension);
	UnsignedLong getDimension() const;

	/** Method save() stores the object through the StorageManager */
	virtual void save(StorageManager::Advocate & adv) const;

	/** Method load() reloads the object from the StorageManager */
	virtual void load(StorageManager::Advocate & adv);	

      protected:

      private:
	/** Find the smallest n such that Binomial(n, n + dimension) > index and also returns the value of Binomial(n, n + dimension) */
	UnsignedLong findBinomialCoefficient(const UnsignedLong index, const UnsignedLong dimension, UnsignedLong & BinomialCoefficient) const;

	// The enumerate function maps N into N^dimension
	UnsignedLong dimension_;

      } ; /* class EnumerateFunction */


    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_ENUMERATEFUNCTION_HXX */
