//                                               -*- C++ -*-
/**
 *  @file  Event.hxx
 *  @brief This class specializes the concept of RandomVector by constructing a Bernoulli
 *
 *  (C) Copyright 2005-2010 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2010-02-04 16:44:49 +0100 (jeu. 04 févr. 2010) $
 *  Id:      $Id: Event.hxx 1473 2010-02-04 15:44:49Z dutka $
 */
#ifndef OPENTURNS_EVENT_HXX
#define OPENTURNS_EVENT_HXX

#include "RandomVector.hxx"
#include "Pointer.hxx"
#include "ComparisonOperator.hxx"

namespace OpenTURNS {

  namespace Uncertainty {

    namespace Algorithm {
      class Simulation;
    }
    namespace Model {


      /**
       * @class Event
       *
       * The class that implements all random vectors
       */
      class Event 
	: public RandomVector
      {
	CLASSNAME;

      public:

	typedef RandomVector::ComparisonOperator       ComparisonOperator;
	typedef RandomVector::InvalidArgumentException InvalidArgumentException;
	/** Constructor from RandomVector */
	Event(const RandomVector & antecedent,
	      const ComparisonOperator & op,
	      const NumericalScalar threshold,
	      const String & name = OT::DefaultName)
	  /* throw (InvalidArgumentException) */;


	/** String converter */
	String __repr__() const;

	/** String converter */
	String __str__() const;

      protected:
        /** for save/load mecanism */
        Event() {}
        friend class Algorithm::Simulation;
      private:

      }; /* class Event */


    } /* namespace Model */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_EVENT_HXX */
