//                                               -*- C++ -*-
/**
 *  @file  HistoryStrategy.hxx
 *  @brief 
 *
 *  (C) Copyright 2005-2010 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2010-02-04 16:44:49 +0100 (jeu. 04 févr. 2010) $
 *  Id:      $Id: HistoryStrategy.hxx 1473 2010-02-04 15:44:49Z dutka $
 */
#ifndef OPENTURNS_HISTORYSTRATEGY_HXX
#define OPENTURNS_HISTORYSTRATEGY_HXX

#include "HistoryStrategyImplementation.hxx"
#include "Pointer.hxx"
#include "TypedInterfaceObject.hxx"

namespace OpenTURNS
{

  namespace Base 
  {

    namespace Stat
    {

      /**
       * @class HistoryStrategy
       */

      class HistoryStrategy
	: public Common::TypedInterfaceObject<HistoryStrategyImplementation>
      {

	CLASSNAME;

      public:

	typedef HistoryStrategyImplementation::NumericalPoint  NumericalPoint;
	typedef Common::Pointer<HistoryStrategyImplementation> Implementation;

	/** Default constructor */
	explicit HistoryStrategy();

	/** Constructor with parameters */
        HistoryStrategy(const HistoryStrategyImplementation & implementation);

	/** Constructor with parameters */
        HistoryStrategy(Implementation & p_implementation);

	/** Store the point according to the strategy */
	void store(const NumericalPoint & point);

	/** Reset the history storage through the isInitialized_ flag */
	void reset();

	/** History sample accessor */
	NumericalSample getSample() const;

	/** String converter */
	String __repr__() const;

      } ; /* class HistoryStrategy */

    } /* namespace Stat */
  } /* namespace Base */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_HISTORYSTRATEGY_HXX */
