//                                               -*- C++ -*-
/**
 *  @file  InverseNatafEllipticalCopulaEvaluation.hxx
 *  @brief Class for the InverseNataf transformation evaluation for elliptical
 *
 *  (C) Copyright 2005-2010 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2010-02-04 16:44:49 +0100 (jeu. 04 févr. 2010) $
 *  Id:      $Id: InverseNatafEllipticalCopulaEvaluation.hxx 1473 2010-02-04 15:44:49Z dutka $
 */
#ifndef OPENTURNS_INVERSENATAFELLIPTICALCOPULAEVALUATION_HXX
#define OPENTURNS_INVERSENATAFELLIPTICALCOPULAEVALUATION_HXX

#include "OTprivate.hxx"
#include "NumericalMathEvaluationImplementation.hxx"
#include "Matrix.hxx"
#include "SquareMatrix.hxx"
#include "NumericalPoint.hxx"
#include "Distribution.hxx"
#include "Exception.hxx"

namespace OpenTURNS {

  namespace Uncertainty {

    namespace Algorithm {


      /**
       * @class InverseNatafEllipticalCopulaEvaluation
       *
       * This class offers an interface for the InverseNataf function for elliptical distributions
       */
      class InverseNatafEllipticalCopulaEvaluation
	: public Base::Func::NumericalMathEvaluationImplementation
      {
	CLASSNAME;
      public:

	typedef Base::Func::NumericalMathEvaluationImplementation NumericalMathEvaluationImplementation;
	typedef Base::Type::Matrix                              Matrix;
	typedef Base::Type::SquareMatrix                        SquareMatrix;
	typedef Base::Type::NumericalPoint                      NumericalPoint;
	typedef Model::Distribution                             Distribution;
	typedef Base::Common::InternalException                 InternalException;
	typedef Base::Common::InvalidArgumentException          InvalidArgumentException;

	/** Parameter constructor */
	InverseNatafEllipticalCopulaEvaluation(const Distribution & standardDistribution,
					       const SquareMatrix & cholesky);


	/** Virtual constructor */
	virtual InverseNatafEllipticalCopulaEvaluation * clone() const;

	/** Evaluation */
	NumericalPoint operator () (const NumericalPoint & in) const
	  /* throw (InvalidArgumentException, InternalException) */;

	/** Gradient according to the marginal parameters */
	virtual Matrix parametersGradient(const NumericalPoint & in) const;
	  
	/** Accessor for input point dimension */
	virtual UnsignedLong getInputDimension() const
	  /* throw(InternalException) */;

	/** Accessor for output point dimension */
	virtual UnsignedLong getOutputDimension() const
	  /* throw(InternalException) */;

	/** String converter */
	virtual String __repr__() const;

      protected:

    
      private:
	Distribution standardDistribution_;
	Matrix cholesky_;

      }; /* InverseNatafEllipticalCopulaEvaluation */


    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_INVERSENATAFELLIPTICALCOPULAEVALUATION_HXX */
