//                                               -*- C++ -*-
/**
 *  @file  LaguerreFactory.hxx
 *  @brief Laguerre polynomial factory
 *
 *  (C) Copyright 2005-2010 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-05-21 17:44:02 +0200 (Wed, 21 May 2008) $
 *  Id:      $Id: Object.hxx 818 2008-05-21 15:44:02Z dutka $
 */
#ifndef OPENTURNS_LAGUERREFACTORY_HXX
#define OPENTURNS_LAGUERREFACTORY_HXX

#include "OrthogonalUniVariatePolynomialFactory.hxx"

namespace OpenTURNS
{

  namespace Uncertainty
  {

    namespace Algorithm
    {

      /**
       * @class LaguerreFactory
       *
       * Laguerre polynomial factory
       */

      class LaguerreFactory
	: public OrthogonalUniVariatePolynomialFactory
      {
	CLASSNAME;
      public:

	/** Default constructor, associated with the default Gamma distribution which is equal to the Exponential distribution */
	LaguerreFactory();

	/** Parameter constructor: k is the order of the generalized Laguerre polynomial, associated with the Gamma(k+1, 1, 0) distribution */
	LaguerreFactory(const NumericalScalar k);

	/** Virtual constructor */
	LaguerreFactory * clone() const;

	/** Calculate the coefficients of recurrence a0n, a1n, a2n such that
            Pn+1(x) = (a0n * x + a1n) * Pn(x) + a2n * Pn-1(x) */
	Coefficients getRecurrenceCoefficients(const UnsignedLong n) const;

	/** K accessor */
	NumericalScalar getK() const;

	/** String converter */
	String __repr__() const;

      private:
	/** Parameter of the Laguerre polynomial */
	NumericalScalar k_;
     
      } ; /* class LaguerreFactory */
      

    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_LAGUERREFACTORY_HXX */
