//                                               -*- C++ -*-
/**
 *  @file  MarginalTransformationGradient.hxx
 *  @brief Class for the Nataf transformationGradient evaluation for elliptical
 *
 *  (C) Copyright 2005-2010 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2010-02-04 16:44:49 +0100 (jeu. 04 févr. 2010) $
 *  Id:      $Id: MarginalTransformationGradient.hxx 1473 2010-02-04 15:44:49Z dutka $
 */
#ifndef OPENTURNS_MARGINALTRANSFORMATIONGRADIENT_HXX
#define OPENTURNS_MARGINALTRANSFORMATIONGRADIENT_HXX

#include "OTprivate.hxx"
#include "NumericalMathGradientImplementation.hxx"
#include "MarginalTransformationEvaluation.hxx"
#include "Matrix.hxx"
#include "NumericalPoint.hxx"
#include "Exception.hxx"

namespace OpenTURNS {

  namespace Uncertainty {

    namespace Algorithm {


      /**
       * @class MarginalTransformationGradient
       *
       * This class offers an interface for the Nataf function for elliptical distributions
       */
      class MarginalTransformationGradient
	: public Base::Func::NumericalMathGradientImplementation
      {
	CLASSNAME;
      public:

	typedef Base::Func::NumericalMathGradientImplementation NumericalMathGradientImplementation; // Required by SWIG
	typedef Base::Type::Matrix                              Matrix;
	typedef Base::Type::NumericalPoint                      NumericalPoint;
	typedef Model::Distribution                             Distribution;
	typedef Base::Type::Collection<Distribution>            DistributionCollection;
	typedef Base::Common::InternalException                 InternalException;
	typedef Base::Common::InvalidArgumentException          InvalidArgumentException;

	/** Parameter constructor */
	MarginalTransformationGradient(const MarginalTransformationEvaluation & evaluation);


	/** Virtual constructor */
	virtual MarginalTransformationGradient * clone() const;

	/** Gradient */
	Matrix gradient(const NumericalPoint & in) const
	  /* throw (InvalidArgumentException, InternalException) */;
	  
	/** Accessor for input point dimension */
	virtual UnsignedLong getInputDimension() const
	  /* throw(InternalException) */;

	/** Accessor for output point dimension */
	virtual UnsignedLong getOutputDimension() const
	  /* throw(InternalException) */;

	/** String converter */
	virtual String __repr__() const;

      protected:

    
      private:
	// The evaluation class associated with the gradient
	MarginalTransformationEvaluation evaluation_;

      }; /* MarginalTransformationGradient */


    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_MARGINALTRANSFORMATIONGRADIENT_HXX */
