//                                               -*- C++ -*-
/**
 *  @file  RiskyAndFast.hxx
 *  @brief Find the roots in a given direction according to the Proban
 *
 *  (C) Copyright 2005-2010 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2010-02-04 16:44:49 +0100 (jeu. 04 févr. 2010) $
 *  Id:      $Id: RiskyAndFast.hxx 1473 2010-02-04 15:44:49Z dutka $
 */
#ifndef OPENTURNS_RISKYANDFAST_HXX
#define OPENTURNS_RISKYANDFAST_HXX

#include "RootStrategyImplementation.hxx"

namespace OpenTURNS
{

  namespace Uncertainty 
  {

    namespace Algorithm
    {

      /**
       * @class RiskyAndFast
       */

      class RiskyAndFast :
	public RootStrategyImplementation
      {

	CLASSNAME;
      public:

	typedef RootStrategyImplementation::NumericalScalarCollection NumericalScalarCollection;
	typedef RootStrategyImplementation::Solver                    Solver;
	typedef RootStrategyImplementation::NumericalMathFunction     NumericalMathFunction;
	typedef RootStrategyImplementation::InternalException         InternalException;
	typedef RootStrategyImplementation::InvalidDimensionException InvalidDimensionException;

	/** Default constructor */
	explicit RiskyAndFast();

	/** Constructor with parameters */
	RiskyAndFast(const Solver & solver);

	/** Constructor with parameters */
	RiskyAndFast(const Solver & solver,
		     const NumericalScalar maximumDistance);


	/** Virtual constructor */
	virtual RiskyAndFast * clone() const;
	
	/** Solve gives all the roots found applying the root strategy */
	NumericalScalarCollection solve(const NumericalMathFunction & function,
					const NumericalScalar value);

	/** String converter */
	String __repr__() const;

      } ; /* class RiskyAndFast */

    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_RISKYANDFAST_HXX */
