//                                               -*- C++ -*-
/**
 *  @file  StandardDistributionPolynomialFactory.hxx
 *  @brief OrthogonalUniVariatePolynomialStandardDistribution polynomial factory
 *
 *  (C) Copyright 2005-2010 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-05-21 17:44:02 +0200 (Wed, 21 May 2008) $
 *  Id:      $Id: Object.hxx 818 2008-05-21 15:44:02Z dutka $
 */
#ifndef OPENTURNS_STANDARDDISTRIBUTIONPOLYNOMIALFACTORY_HXX
#define OPENTURNS_STANDARDDISTRIBUTIONPOLYNOMIALFACTORY_HXX

#include <map>

#include "OrthogonalUniVariatePolynomialFactory.hxx"
#include "OrthonormalizationAlgorithm.hxx"
#include "Collection.hxx"

namespace OpenTURNS
{

  namespace Uncertainty
  {

    namespace Algorithm
    {

      /**
       * @class StandardDistributionPolynomialFactory
       *
       * OrthogonalUniVariatePolynomialStandardDistribution polynomial factory
       */

      class StandardDistributionPolynomialFactory
        : public OrthogonalUniVariatePolynomialFactory
      {
        CLASSNAME;
      public:

        typedef Base::Type::Collection<NumericalScalar> NumericalScalarCollection;
        typedef std::map<UnsignedLong, NumericalScalar> NumericalScalarCache;

        /** Default constructor */
        StandardDistributionPolynomialFactory();

        /** Parameter constructor */
        StandardDistributionPolynomialFactory(const Distribution & distribution);

        /** Parameter constructor with specific orthonormalization algorithm */
        StandardDistributionPolynomialFactory(const OrthonormalizationAlgorithm & orthonormalizationAlgorithm);

        /** Virtual constructor */
        StandardDistributionPolynomialFactory * clone() const;

        /** Calculate the coefficients of recurrence a0, a1, a2 such that
            Pn(x) = (a0 * x + a1) * Pn-1(x) + a2 * Pn-2(x) */
        Coefficients getRecurrenceCoefficients(const UnsignedLong n) const;

        /** String converter */
        String __repr__() const;

      private:
	/** Algorithm used to perform the orthonormalization */
	OrthonormalizationAlgorithm orthonormalizationAlgorithm_;

      } ; /* class StandardDistributionPolynomialFactory */


    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_STANDARDDISTRIBUTIONPOLYNOMIALFACTORY_HXX */
