//                                               -*- C++ -*-
/**
 *  @file  StratifiedExperiment.hxx
 *  @brief Abstract top-level view of an stratifiedExperiment plane
 *
 *  (C) Copyright 2005-2010 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-06-26 13:50:17 +0200 (jeu, 26 jun 2008) $
 *  Id:      $Id: StratifiedExperiment.hxx 862 2008-06-26 11:50:17Z dutka $
 */
#ifndef OPENTURNS_STRATIFIEDEXPERIMENT_HXX
#define OPENTURNS_STRATIFIEDEXPERIMENT_HXX

#include "ExperimentImplementation.hxx"
#include "NumericalPoint.hxx"

namespace OpenTURNS {

  namespace Uncertainty {

    namespace Algorithm {

      /**
       * @class StratifiedExperiment
       *
       * The class describes the probabilistic concept of stratifiedExperiment plan
       */
      class StratifiedExperiment
	: public ExperimentImplementation
      {
	CLASSNAME;
      public:

	typedef Base::Type::NumericalPoint NumericalPoint;

	/** Default constructor */
	explicit StratifiedExperiment(const String & name = OT::DefaultName);

	/** Constructor with parameters */
	explicit StratifiedExperiment(const NumericalPoint & center,
				      const NumericalPoint & levels,
				      const String & name = OT::DefaultName);
	
	/** String converter */
	virtual String __repr__() const;

	/** Center accessor */
	virtual void setCenter(const NumericalPoint & center);

	/** Center accessor */
	virtual NumericalPoint getCenter() const;

	/** Levels accessor */
	virtual void setLevels(const NumericalPoint & levels);

	/** Levels accessor */
	virtual NumericalPoint getLevels() const;

      protected:

	NumericalPoint center_;
	NumericalPoint levels_;

      }; /* class StratifiedExperiment */


    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_STRATIFIEDEXPERIMENT_HXX */
